@@ -3,10 +3,10 @@
 test_that(
   "olink_normalization_is_bridgeable - works",
   {
-    
+
     skip_if_not(file.exists(test_path("data","example_3k_data.rds")))
     skip_if_not(file.exists(test_path("data","example_HT_data.rds")))
-    
+
     data_3k <- get_example_data(filename = "example_3k_data.rds")
     data_ht <- get_example_data(filename = "example_HT_data.rds")
 
@@ -118,7 +118,7 @@ test_that(
 test_that(
   "olink_normalization_qs - works - compare to reference",
   {
-    
+
     skip_if_not(file.exists(test_path("data","example_3k_data.rds")))
     skip_if_not(file.exists(test_path("data","example_HT_data.rds")))
 
@@ -214,7 +214,7 @@ test_that(
 test_that(
   "olink_normalization_qs - works - expected output, all bridge samples",
   {
-    
+
     skip_if_not(file.exists(test_path("data","example_3k_data.rds")))
     skip_if_not(file.exists(test_path("data","example_HT_data.rds")))
 
@@ -338,7 +338,7 @@ test_that(
 test_that(
   "olink_normalization_qs - works - expected output, 50 bridge samples",
   {
-    
+
     skip_if_not(file.exists(test_path("data","example_3k_data.rds")))
     skip_if_not(file.exists(test_path("data","example_HT_data.rds")))
 
@@ -459,3 +459,174 @@ test_that(
     )
   }
 )
+
+
+# Test olink_normalization_product_format ----
+
+test_that(
+  "olink_normalization_product_format - works",
+  {
+    skip_if_not(file.exists(test_path("data","example_3k_data.rds")))
+    skip_if_not(file.exists(test_path("data","example_HT_data.rds")))
+
+    data_3k <- get_example_data(filename = "example_3k_data.rds")
+    data_ht <- get_example_data(filename = "example_HT_data.rds")
+
+    expect_message(expect_warning(
+      object = norm_br_data_format <- olink_normalization(
+          df1 = data_3k,
+          df2 = data_ht,
+          overlapping_samples_df1 = intersect(
+            x = unique(data_3k$SampleID),
+            y = unique(data_ht$SampleID)
+          ) |>
+            (\(x) x[!grepl("CONTROL", x)])(),
+          overlapping_samples_df2 = NULL,
+          df1_project_nr = "P1",
+          df2_project_nr = "P2",
+          reference_project = "P2",
+          reference_medians = NULL,
+          format = TRUE # format data
+        ),
+      regexp = "2 assays are not shared across products."),
+      regexp = "Cross-product normalization will be performed!"
+    )
+
+
+    # unformatted data
+    expect_message(expect_warning(
+      object = norm_br_data <- olink_normalization(
+      df1 = data_3k,
+      df2 = data_ht,
+      overlapping_samples_df1 = intersect(
+        x = unique(data_3k$SampleID),
+        y = unique(data_ht$SampleID)
+      ) |>
+        (\(x) x[!grepl("CONTROL", x)])(),
+      overlapping_samples_df2 = NULL,
+      df1_project_nr = "P1",
+      df2_project_nr = "P2",
+      reference_project = "P2",
+      reference_medians = NULL # format data
+    ),
+    regexp = "2 assays are not shared across products."),
+    regexp = "Cross-product normalization will be performed!"
+  )
+
+    expect_warning(
+      object = norm_br_data_format_function <-
+        olink_normalization_product_format(bridged_df = norm_br_data,
+                                           df1 = data_ht,
+                                           df1_project_nr = "P2",
+                                           df2 = data_3k,
+                                           df2_project_nr = "P1"),
+      regexp = NA)
+
+    ## check that function works both ways
+    expect_equal(
+      object = dim(norm_br_data_format),
+      expected = dim(norm_br_data_format_function)
+    )
+
+    ## check that correct columns are removed
+    expect_equal(
+      object = length(intersect(colnames(norm_br_data_format),
+                         c("MedianCenteredNPX",
+                           "QSNormalizedNPX", "OlinkID_E3072"))),
+      expected = 0L
+    )
+
+    ## check that NotBridgeable assays get their own OlinkIDs
+    expect_equal(
+      object = norm_br_data_format |>
+        dplyr::filter(.data[["BridgingRecommendation"]] == "NotBridgeable") |>
+        dplyr::select(all_of("OlinkID")) |>
+        dplyr::distinct() |>
+        dplyr::pull(),
+      expected = c("OID20054", "OID41012")
+    )
+
+
+    ## check that NPX is being replaced correctly
+    npx_bridging_recs <- norm_br_data |>
+      dplyr:::mutate(SampleID = paste0(.data[["SampleID"]],
+                                       "_",
+                                       .data[["Project"]])) |>
+      dplyr::mutate(OlinkID =  paste0(
+        .data[["OlinkID"]],
+        "_",
+        .data[["OlinkID_E3072"]])) |>
+      dplyr::select(c("SampleID",
+                      "OlinkID",
+                      "Block",
+                      "BridgingRecommendation",
+                      "MedianCenteredNPX",
+                      "QSNormalizedNPX"))
+
+    npx_assignment_check <- norm_br_data_format |>
+      dplyr::filter(!.data[["BridgingRecommendation"]] %in% c("NotBridgeable","NotOverlapping")) |>
+      dplyr::left_join(npx_bridging_recs |>
+                         rename(BridgingRecommendationOriginal = all_of("BridgingRecommendation")),
+                by = c("SampleID",
+                       "OlinkID",
+                       "Block")) |>
+      dplyr::filter(.data[["Project"]] == "P1") |>
+      dplyr::mutate(replace_flag = case_when(
+        .data[["BridgingRecommendationOriginal"]] == "MedianCentering" &
+          .data[["NPX"]] == .data[["MedianCenteredNPX"]] ~ "Correct",
+        .data[["BridgingRecommendationOriginal"]] == "QuantileSmoothing" &
+          .data[["NPX"]] == .data[["QSNormalizedNPX"]] ~ "Correct",
+        TRUE ~ "Incorrect"
+      ))
+
+    expect_equal(
+      object = npx_assignment_check |>
+        dplyr::filter(.data[["replace_flag"]] == "Incorrect") |>
+        nrow(),
+      expected = 0L
+    )
+
+    ## check that the numbers of assay assignments are correct
+    expect_equal(
+      object = norm_br_data_format |>
+        select(OlinkID, BridgingRecommendation) |>
+        distinct() |>
+        filter(BridgingRecommendation == "NotOverlapping") |>
+        tally() |>
+        pull(),
+      expected = 2L
+    )
+
+    expect_equal(
+      object = norm_br_data_format |>
+        select(OlinkID, BridgingRecommendation) |>
+        distinct() |>
+        filter(BridgingRecommendation == "NotBridgeable") |>
+        tally() |>
+        pull(),
+      expected = 2L
+    )
+
+    expect_equal(
+      object = norm_br_data_format |>
+        select(OlinkID, BridgingRecommendation) |>
+        distinct() |>
+        filter(BridgingRecommendation == "MedianCentering") |>
+        tally() |>
+        pull(),
+      expected = 40L
+    )
+
+    expect_equal(
+      object = norm_br_data_format |>
+        select(OlinkID, BridgingRecommendation) |>
+        distinct() |>
+        filter(BridgingRecommendation == "QuantileSmoothing") |>
+        tally() |>
+        pull(),
+      expected = 63L
+    )
+
+  }
+)
+
